CREATE SCHEMA IF NOT EXISTS `E_Hospital` DEFAULT CHARACTER SET utf8 ;
USE `E_Hospital` ;

CREATE TABLE IF NOT EXISTS `E_Hospital`.`medication` (
  `medicationt_id` INT NOT NULL,
  `name` VARCHAR(45) NOT NULL,
  `expire_date` DATE NOT NULL,
  `price` DECIMAL(11) NOT NULL,
  PRIMARY KEY (`medicationt_id`))
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`patient_prescription` (
  `prescription_id` INT NOT NULL,
  `medication_id` INT NOT NULL,
  `medication_status` VARCHAR(45) NOT NULL,
  `description` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`prescription_id`),
  INDEX `medication_id_idx` (`medication_id` ASC) VISIBLE,
  CONSTRAINT `medication_id`
    FOREIGN KEY (`medication_id`)
    REFERENCES `E_Hospital`.`medication` (`medicationt_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`product` (
  `id` INT NOT NULL,
  `name` VARCHAR(45) NULL,
  `price` VARCHAR(45) NULL,
  PRIMARY KEY (`id`))
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`medical_recomendation` (
  `id` INT NOT NULL,
  `medcation_description` INT NOT NULL,
  `product_id` INT NULL,
  PRIMARY KEY (`id`),
  INDEX `medication_description_idx` (`medcation_description` ASC) VISIBLE,
  INDEX `product_id_idx` (`product_id` ASC) VISIBLE,
  CONSTRAINT `medication_description`
    FOREIGN KEY (`medcation_description`)
    REFERENCES `E_Hospital`.`patient_prescription` (`prescription_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `product_id`
    FOREIGN KEY (`product_id`)
    REFERENCES `E_Hospital`.`product` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`Diagnosis` (
  `diagnosis_id` INT NOT NULL,
  `description` VARCHAR(500) NOT NULL,
  `medical_recomendation` INT NOT NULL,
  PRIMARY KEY (`diagnosis_id`),
  INDEX `medical_recomendation_idx` (`medical_recomendation` ASC) VISIBLE,
  CONSTRAINT `medical_recomendation`
    FOREIGN KEY (`medical_recomendation`)
    REFERENCES `E_Hospital`.`medical_recomendation` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`speciality` (
  `id` INT NOT NULL,
  `practice_type` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`id`))
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`physician` (
  `employeeID` INT NOT NULL,
  `name` VARCHAR(45) NOT NULL,
  `medical_practice_number` VARCHAR(50) NOT NULL,
  `phone_number` VARCHAR(45) NOT NULL,
  `email` VARCHAR(45) NOT NULL,
  `specialized_with` INT NOT NULL,
  PRIMARY KEY (`employeeID`),
  INDEX `specialized_with_idx` (`specialized_with` ASC) VISIBLE,
  CONSTRAINT `specialized_with`
    FOREIGN KEY (`specialized_with`)
    REFERENCES `E_Hospital`.`speciality` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`physician_schedule` (
  `schedule_id` INT NOT NULL,
  `schedule_shift` VARCHAR(45) NOT NULL,
  `physician_id` INT NOT NULL,
  `room_number` INT NOT NULL,
  `maximum_patient` INT NOT NULL,
  PRIMARY KEY (`schedule_id`),
  INDEX `physician_id_idx` (`physician_id` ASC) VISIBLE,
  CONSTRAINT `physician_id`
    FOREIGN KEY (`physician_id`)
    REFERENCES `E_Hospital`.`physician` (`employeeID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`patient_referral` (
  `referral_code` INT NOT NULL,
  `description` VARCHAR(45) NOT NULL,
  `referral_date` DATE NOT NULL,
  `priority` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`referral_code`))
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`appointment_detail` (
  `appointment_ID` INT NOT NULL,
  `available_physician` VARCHAR(45) NOT NULL,
  `number_of_capacity` INT NOT NULL,
  `alloted_daignosis` INT NOT NULL,
  `alloted_schedule` INT NOT NULL,
  `referral_code` INT NULL,
  PRIMARY KEY (`appointment_ID`),
  INDEX `alloted_daignosis_idx` (`alloted_daignosis` ASC) VISIBLE,
  INDEX `alloted_schedule_idx` (`alloted_schedule` ASC) VISIBLE,
  INDEX `referral_code_idx` (`referral_code` ASC) VISIBLE,
  CONSTRAINT `alloted_daignosis`
    FOREIGN KEY (`alloted_daignosis`)
    REFERENCES `E_Hospital`.`Diagnosis` (`diagnosis_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `alloted_schedule`
    FOREIGN KEY (`alloted_schedule`)
    REFERENCES `E_Hospital`.`physician_schedule` (`schedule_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `referral_code`
    FOREIGN KEY (`referral_code`)
    REFERENCES `E_Hospital`.`patient_referral` (`referral_code`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`patientInfo` (
  `email` VARCHAR(45) NOT NULL,
  `name` VARCHAR(100) NOT NULL,
  `date_of_birth` DATE NOT NULL,
  `mobile` VARCHAR(45) NULL,
  `address` VARCHAR(100) NOT NULL,
  `weight` DECIMAL(3) NOT NULL,
  `height` DECIMAL(3) NOT NULL,
  `blood_group` VARCHAR(45) NOT NULL,
  `patient_illness` VARCHAR(45) NOT NULL,
  `desease_description` VARCHAR(45) NOT NULL,
  `booked_appointment` INT NOT NULL,
  PRIMARY KEY (`email`),
  INDEX `booked_appointment_idx` (`booked_appointment` ASC) VISIBLE,
  CONSTRAINT `booked_appointment`
    FOREIGN KEY (`booked_appointment`)
    REFERENCES `E_Hospital`.`appointment_detail` (`appointment_ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


CREATE TABLE IF NOT EXISTS `E_Hospital`.`employee_detail` (
  `emp_id` INT NOT NULL,
  `name` VARCHAR(45) NOT NULL,
  `phone` VARCHAR(45) NOT NULL,
  `email` VARCHAR(45) NOT NULL,
  `specialized_with` INT NOT NULL,
  PRIMARY KEY (`emp_id`),
  INDEX `specialized_with_idx` (`specialized_with` ASC) VISIBLE,
  CONSTRAINT `specialized_with`
    FOREIGN KEY (`specialized_with`)
    REFERENCES `E_Hospital`.`speciality` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;

